﻿'A reference to the Phidget22.NET.dll must be added to new projects in VB.Net 
'From the "Project" menu select "Add Reference" 
'From the "Add Reference" window select the "Browse" tab 
'Browse to the directory you installed the Phidgets library to 
'The default is "C:\Program Files\Phidgets" 
'Select "Phidget22.NET.dll" and click "OK" 
'To view objects that have been added, select the "View" menu 
'Select "Object Browser" 
'Then expand the Phidget22.NET.dll item 



Imports Phidget22
Imports Phidget22.Events

Public Class Form1
    Dim WithEvents dictionary As Phidget22.Dictionary
    Dim open As ExampleUtils.ExampleUtils.CommandLineOpen
    Dim errorBox As ErrorEventBox
    Dim addEntryForm As AddEntry

    Public Sub New()
        open = New ExampleUtils.ExampleUtils.CommandLineOpen(Me)
        Phidget22.Phidget.InvokeEventCallbacks = True
        InitializeComponent()
    End Sub

    Public Sub New(ByVal commandLine As String())
        open = New ExampleUtils.ExampleUtils.CommandLineOpen(Me)
        open.commandLine = commandLine
        Phidget22.Phidget.InvokeEventCallbacks = True
        InitializeComponent()
    End Sub

    Private Sub Form1_Load(sender As Object, e As EventArgs) Handles MyBase.Load
        errorBox = New ErrorEventBox(Me)
        dictionary = New Phidget22.Dictionary()

        If open.commandLine.Length = 1 Then 'if there is no commandline parameter then we need to create a new dictionary for test use
            Phidget22.Dictionary.AddDictionary(5000, "Test Dictionary")
            Try
                dictionary.DeviceSerialNumber = 5000
                dictionary.Open()
            Catch ex As PhidgetException
                errorBox.addMessage("Error opening dictionary: " + ex.Message)
            End Try
        Else 'otherwise, attempt to open the specified dictionary
            Try
                Dim phidgetParameters As ExampleUtils.commandLineData = open.parseCmdLine()

                Try 'set all the values grabbed from command line.  these values have defaults that are set in ExampleUtils.vb, you can check there to see them
                    dictionary.Channel = phidgetParameters.Channel 'selects the channel on the device to open
                    dictionary.DeviceSerialNumber = phidgetParameters.SerialNumber 'selects the device or hub to open
                    dictionary.HubPort = phidgetParameters.HubPort 'selects th eport on the hub to open
                    dictionary.IsHubPortDevice = phidgetParameters.isHubPortDevice 'is the device a port on a vint hub?

                    If phidgetParameters.isRemote Then 'are we trying to open a remote device?
                        dictionary.IsRemote = True
                        Net.EnableServerDiscovery(ServerType.Device) 'turn on network scan
                        If phidgetParameters.Password <> vbNullString And phidgetParameters.ServerName <> vbNullString Then
                            Net.SetServerPassword(phidgetParameters.ServerName, phidgetParameters.Password)
                        End If
                    Else
                        dictionary.IsLocal = True
                    End If

                    dictionary.Open() 'open the device specified by the above parameters
                Catch ex As PhidgetException
                    errorBox.addMessage("Error opening the device: " + ex.Message)
                End Try
            Catch ex As PhidgetException
                errorBox.addMessage("Error connecting to dictionary server: " + ex.Message)
            End Try
        End If
    End Sub

    Private Sub Form1_FormClosing(sender As Object, e As FormClosingEventArgs) Handles MyBase.FormClosing
        dictionary.Close()
        If dictionary.DeviceSerialNumber = 5000 Then
            Try
                Phidget22.Dictionary.RemoveDictionary(5000)
            Catch ex As PhidgetException
                errorBox.addMessage("Error removing dictionary: " + ex.Message)
            End Try
        End If

        If (addEntryForm IsNot Nothing) Then
            addEntryForm.Close()
        End If
    End Sub

    Private Sub dict_Attach(sender As Object, e As Phidget22.Events.AttachEventArgs) Handles dictionary.Attach
        Dim attachedDictionary As Phidget22.Dictionary = CType(sender, Phidget22.Dictionary)
        dictSerialTxt.Text = attachedDictionary.DeviceSerialNumber.ToString()
        dictTxt.Text = attachedDictionary.DeviceLabel

        'get a list of the dictionary contents
        Dim keys As String() = dictionary.Scan(Nothing) 'scan returns a limited number of keys so for large dictionarys you may have to run scan multiple times.  "nothing" will start at the beginning
        While (keys.Length > 0)
            'populate the form with the dictionary contents
            For Each element As String In keys
                dictionaryTable.Rows.Add(element, dictionary.Get(element))
            Next

            keys = dictionary.Scan(keys(keys.Length - 1)) 'now we scan beginning at the key which was the last key we previously scanned
        End While
    End Sub

    Private Sub dict_Detach(sender As Object, e As Phidget22.Events.DetachEventArgs) Handles dictionary.Detach
        dictionaryTable.Rows.Clear()
    End Sub

    Private Sub dict_Error(sender As Object, e As Phidget22.Events.ErrorEventArgs) Handles dictionary.Error
        errorBox.addMessage(e.Description)
    End Sub

    Private Sub dict_Update(sender As Object, e As Phidget22.Events.DictionaryKeyValueUpdateEventArgs) Handles dictionary.KeyValueUpdate
        For Each row As DataGridViewRow In dictionaryTable.Rows 'go through the table
            If row.Cells(0).Value.ToString() = e.Key Then ' find the row with the matching key
                row.Cells(1).Value = e.Value 'update with the new value
                Return 'stop looking
            End If
        Next
    End Sub

    Private Sub dict_Add(sender As Object, e As Phidget22.Events.DictionaryKeyAddEventArgs) Handles dictionary.KeyAdd 'a new entry has been added to the dictionary, update the form to reflect this
        dictionaryTable.Rows.Add(e.Key, e.Value)
    End Sub

    Private Sub dict_Remove(sender As Object, e As Phidget22.Events.DictionaryKeyRemoveEventArgs) Handles dictionary.KeyRemove 'an entry has been removed from the dictionary, update the form to reflect this
        Dim indexToDelete As Integer = -1
        For Each row As DataGridViewRow In dictionaryTable.Rows 'scan the table
            If row.Cells(0).ToString() = e.Key Then 'find the row with the deleted key
                indexToDelete = row.Index
                Exit For
            End If
        Next
        If indexToDelete >= 0 Then 'delete the row with the deleted key
            dictionaryTable.Rows.RemoveAt(indexToDelete)
        End If
    End Sub

    Private Sub addKey_Click(sender As Object, e As EventArgs) Handles addKey.Click
        addEntryForm = New AddEntry()
        Dim result As VariantType = addEntryForm.ShowDialog()
        If result = DialogResult.OK Then
            Try
                dictionary.Add(addEntryForm.key, addEntryForm.value)
            Catch ex As PhidgetException
                errorBox.addMessage("Error adding key: " + ex.Message)
            End Try
        End If
    End Sub

    Private Sub removeKey_Click(sender As Object, e As EventArgs) Handles removeKey.Click
        For Each selection As DataGridViewRow In dictionaryTable.SelectedRows
            dictionary.Remove(selection.Cells(0).Value.ToString())
            dictionaryTable.Rows.Remove(selection)
        Next
    End Sub
End Class
